@@ -4,7 +4,7 @@
 
   \author Satofumi KAMIMURA
 
-  $Id: BatmonWidget.cpp 27 2010-01-02 01:43:56Z satofumi $
+  $Id: BatmonWidget.cpp 33 2010-01-06 09:12:34Z satofumi $
 */
 
 #include "BatmonWidget.h"
@@ -55,6 +55,7 @@ struct BatmonWidget::pImpl
   vector<QAction*> skin_actions_;
   bool is_masked_;
 
+  bool is_tray_available_;
   QSystemTrayIcon tray_icon_;
 
 
@@ -62,7 +63,8 @@ struct BatmonWidget::pImpl
     : widget_(widget),
       battery_state_(Unknown), previous_battery_state_(Unknown),
       percent_(0), previous_percent_(0), character_index_(0),
-      hide_checked_(false), hide_action_(NULL), is_masked_(false)
+      hide_checked_(false), hide_action_(NULL), is_masked_(false),
+      is_tray_available_(QSystemTrayIcon::isSystemTrayAvailable())
   {
   }
 
@@ -224,13 +226,13 @@ struct BatmonWidget::pImpl
     if (hide_checked_ && (battery_state_ == Charging)) {
       // 充電中に描画しないよう指定されているときは隠す
       widget_->hide();
-      if (QSystemTrayIcon::isSystemTrayAvailable()) {
+      if (is_tray_available_) {
         tray_icon_.show();
       }
     } else {
       if ((! repainted) && widget_->isHidden()) {
         widget_->show();
-        if (QSystemTrayIcon::isSystemTrayAvailable()) {
+        if (is_tray_available_) {
           tray_icon_.hide();
         }
       }
@@ -280,7 +282,7 @@ struct BatmonWidget::pImpl
       if (remaining_time == 0.0) {
 	return QString(tr("remaining: %1 [%]")).arg(percent_);
       } else {
-	return QString(tr("remaining: %1 [h]")).arg(remaining_time, 0, 'g', 1);
+	return QString(tr("remaining: %1 [h] (%2 [%])")).arg(remaining_time, 0, 'g', 1).arg(percent_);
       }
       break;
 
@@ -312,7 +314,7 @@ BatmonWidget::BatmonWidget(bool geometry_specified, QWidget* widget)
   pimpl->loadSettings(! geometry_specified);
   pimpl->initializeCharacters();
   pimpl->initializeMenu();
-  if (QSystemTrayIcon::isSystemTrayAvailable()) {
+  if (pimpl->is_tray_available_) {
     // システムトレイが利用可能ならば登録
     pimpl->initializeSystemTray();
   }
