@@ -4,47 +4,47 @@
 <context>
     <name>BatmonWidget</name>
     <message>
-        <location filename="BatmonWidget.cpp" line="92"/>
+        <location filename="BatmonWidget.cpp" line="94"/>
         <source>girl</source>
         <translation>女の子</translation>
     </message>
     <message>
-        <location filename="BatmonWidget.cpp" line="102"/>
+        <location filename="BatmonWidget.cpp" line="104"/>
         <source>pengui</source>
         <translation>りもペンギン</translation>
     </message>
     <message>
-        <location filename="BatmonWidget.cpp" line="131"/>
+        <location filename="BatmonWidget.cpp" line="133"/>
         <source>Hide while charging</source>
         <translation>充電中は表示しない</translation>
     </message>
     <message>
-        <location filename="BatmonWidget.cpp" line="141"/>
+        <location filename="BatmonWidget.cpp" line="143"/>
         <source>Ctrl+Q</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="BatmonWidget.cpp" line="153"/>
+        <location filename="BatmonWidget.cpp" line="155"/>
         <source>APM Battery Monitor</source>
         <translation>APM ばってりーもにたー</translation>
     </message>
     <message>
-        <location filename="BatmonWidget.cpp" line="276"/>
+        <location filename="BatmonWidget.cpp" line="278"/>
         <source>charging: %1 [%]</source>
         <translation>充電中: %1 [%]</translation>
     </message>
     <message>
-        <location filename="BatmonWidget.cpp" line="281"/>
+        <location filename="BatmonWidget.cpp" line="283"/>
         <source>remaining: %1 [%]</source>
         <translation>容量: %1 [%]</translation>
     </message>
     <message>
-        <location filename="BatmonWidget.cpp" line="283"/>
-        <source>remaining: %1 [h]</source>
-        <translation>残り時間: %1 [h]</translation>
+        <location filename="BatmonWidget.cpp" line="285"/>
+        <source>remaining: %1 [h] (%2 [%])</source>
+        <translation>残り: %1 [h] (%2 [%])</translation>
     </message>
     <message>
-        <location filename="BatmonWidget.cpp" line="289"/>
+        <location filename="BatmonWidget.cpp" line="291"/>
         <source>unknown system</source>
         <translation>不明なシステム</translation>
     </message>
@@ -52,7 +52,7 @@
 <context>
     <name>QAction</name>
     <message>
-        <location filename="BatmonWidget.cpp" line="140"/>
+        <location filename="BatmonWidget.cpp" line="142"/>
         <source>Quit</source>
         <translation>終了</translation>
     </message>
